# shorten_url
<!-- ALL-CONTRIBUTORS-BADGE:START - Do not remove or modify this section -->
[![MIT license](https://img.shields.io/badge/License-MIT-blue.svg)](https://lbesson.mit-license.org/)
<!-- ALL-CONTRIBUTORS-BADGE:END -->

Python Library to help you short and expand urls using https://rel.ink/

## Installation

In order install this package, simply run:

```bash
pip install shorten_url
```

## Usage

To use shorten_url, you first need to import the package:

```python
import shorten_url
```

### Shorten the URL:

```python
shorten_url.short("https://www.linkedin.com/in/salil-gautam/")    # Returns the shortened URL.
```

### Expand the URL:

```python
shorten_url.expand("https://rel.ink/goqDVn")    # Returns the expanded URL.
```




## Contributors ✨

Thanks goes to these wonderful people ([emoji key](https://allcontributors.org/docs/en/emoji-key)):

<!-- ALL-CONTRIBUTORS-LIST:START - Do not remove or modify this section -->
<!-- prettier-ignore-start -->
<!-- markdownlint-disable -->
<table>
  <tr>
    <td align="center"><a href="https://github.com/salil-gtm"><img src="https://avatars2.githubusercontent.com/u/18382251?v=4" width="100px;" alt=""/><br /><sub><b>Salil Gautam</b></sub></a><br /><a href="https://github.com/Quarantine-Projects/shorten_url/commits?author=salil-gtm" title="Code">💻</a> <a href="https://github.com/Quarantine-Projects/shorten_url/commits?author=salil-gtm" title="Documentation">📖</a> <a href="#example-salil-gtm" title="Examples">💡</a></td>
  </tr>
</table>

<!-- markdownlint-enable -->
<!-- prettier-ignore-end -->
<!-- ALL-CONTRIBUTORS-LIST:END -->

This project follows the [all-contributors](https://github.com/all-contributors/all-contributors) specification. Contributions of any kind welcome!
